@@ -95,7 +95,7 @@ SchemaAlignment.setUpTabs = function() {
         .hide()
         .appendTo(schemaButton);
  
-  $('.main-view-panel-tab-header').click(function(e) {
+  $('.main-view-panel-tab-header').on('click',function(e) {
      var targetTab = $(this).attr('href');
      SchemaAlignment.switchTab(targetTab);
      e.preventDefault();
@@ -121,26 +121,32 @@ SchemaAlignment._rerenderTabs = function() {
   var schemaElmts = this._schemaElmts = DOM.bind(schemaTab);
   schemaElmts.dialogExplanation.html($.i18n('wikibase-schema/dialog-explanation',
       WikibaseManager.getSelectedWikibaseMainPage(),
-      WikibaseManager.getSelectedWikibaseName(),
-      WikibaseManager.getSelectedWikibaseReconEndpoint().replace("${lang}", "en")));
-  this._plusButton($.i18n('wikibase-schema/add-item-button'), schemaElmts.addItemButton);
-  schemaElmts.addItemButton.click(function(e) {
-    SchemaAlignment._addItem();
-    SchemaAlignment._hasChanged();
-    e.preventDefault();
-  });
+      WikibaseManager.getSelectedWikibaseName()));
+  let editableEntityTypes = WikibaseManager.getSelectedWikibaseEditableEntityTypes();
+  for (let entityType of editableEntityTypes) {
+    let addButton = $('<div></div>').addClass("wbs-toolbar");
+    let link = $('<a></a>').addClass("wbs-add-entity").appendTo(addButton);
+    addButton.appendTo(schemaElmts.entityAddButtons);
+    this._plusButton($.i18n('wikibase-schema/add-'+entityType+'-button'), link);
+    link.on('click',function(e) {
+      SchemaAlignment._addEntity(entityType);
+      SchemaAlignment._hasChanged();
+      e.preventDefault();
+    });
+  }
+  
   schemaElmts.saveButton
       .text($.i18n('wikibase-schema/save-button'))
       .attr('title', $.i18n('wikibase-schema/save-schema-alt'))
       .prop('disabled', true)
       .addClass('disabled')
-      .click(function() { SchemaAlignment._save(); });
+      .on('click',function() { SchemaAlignment._save(); });
   schemaElmts.discardButton
       .text($.i18n('wikibase-schema/discard-button'))
       .attr('title', $.i18n('wikibase-schema/discard-schema-changes-alt'))
       .prop('disabled', true)
       .addClass('disabled')
-      .click(function() { SchemaAlignment._discardChanges(); });
+      .on('click',function() { SchemaAlignment._discardChanges(); });
 
   // Init the column area
   this.updateColumns();
@@ -162,17 +168,24 @@ SchemaAlignment._rerenderTabs = function() {
   previewElmts.invalidSchemaWarningPreview.text($.i18n('wikibase-schema/invalid-schema-warning-preview'));
   this._previewPanes = $(".schema-alignment-dialog-preview");
 
-  var reconServiceURL = WikibaseManager.getSelectedWikibaseReconEndpoint()
-      .replace("${lang}", $.i18n("core-recon/wd-recon-lang"));
-  ReconciliationManager.getOrRegisterServiceFromUrl(reconServiceURL, function (service)  {
-    SchemaAlignment._reconService = service;
+  // add all recon services for all the entity types of the Wikibase instance
+  var entityTypes = WikibaseManager.getSelectedWikibaseAvailableEntityTypes();
+  SchemaAlignment._reconService = {};
+  for (let entityType of entityTypes) {
+    var reconServiceTemplate = WikibaseManager.getSelectedWikibaseReconEndpoint(entityType);
+    if (reconServiceTemplate != null) {
+      var reconServiceURL = reconServiceTemplate.replace("${lang}", $.i18n("core-recon/wd-recon-lang"));
+      ReconciliationManager.getOrRegisterServiceFromUrl(reconServiceURL, function (service)  {
+        SchemaAlignment._reconService[entityType] = service;
+      }, false);
+    }
+  }
 
-    // Load the existing schema
-    SchemaAlignment._reset(theProject.overlayModels.wikibaseSchema);
+  // Load the existing schema
+  SchemaAlignment._reset(theProject.overlayModels.wikibaseSchema);
 
-    // Perform initial preview
-    SchemaAlignment.preview();
-  }, false);
+  // Perform initial preview
+  SchemaAlignment.preview();
 };
 
 SchemaAlignment.onWikibaseChange = function() {
@@ -190,16 +203,18 @@ SchemaAlignment.updateColumns = function() {
   for (var i = 0; i < columns.length; i++) {
      var column = columns[i];
      var reconConfig = column.reconConfig;
-     // make sure the column was reconciled to the target Wikibase
+     // make sure the column was reconciled.
+     // TODO we could potentially ignore any reconciliation to a siteIRI not
+     // mentioned in the manifest…
      var cell = SchemaAlignment._createDraggableColumn(column.name,
-        reconConfig && reconConfig.identifierSpace === WikibaseManager.getSelectedWikibaseSiteIri() && column.reconStats);
+        reconConfig && column.reconStats ? reconConfig.identifierSpace : null);
      this._columnArea.append(cell);
   }
 
   $('.wbs-reconciled-column').draggable({
      helper: "clone",
      cursor: "crosshair",
-     snap: ".wbs-item-input input, .wbs-target-input input",
+     snap: ".wbs-entity-input input, .wbs-target-input input",
      zIndex: 100,
   });
   $('.wbs-unreconciled-column').draggable({
@@ -249,7 +264,7 @@ var beforeUnload = function(e) {
   }
 };
 
-$(window).bind('beforeunload', beforeUnload);
+$(window).on('beforeunload', beforeUnload);
 
 SchemaAlignment._reset = function(schema) {
   if (!schema) {
@@ -264,19 +279,32 @@ SchemaAlignment._reset = function(schema) {
     schema.mediaWikiApiEndpoint = WikidataManifestV1_0.mediawiki.api;
   }
 
-  if (!schema.itemDocuments) {
-    schema.itemDocuments = [];
+  if (!schema.entityEdits) {
+    schema.entityEdits = [];
   }
+  // backwards compatibility for schemas which supported only items (up to OpenRefine 3.5)
+  if (schema.itemDocuments) {
+	for(let itemEdit in schema.itemDocuments) {
+	   schema.entityEdits.push(itemEdit);
+	}
+  }
+  delete schema.itemDocuments;
 
   this._originalSchema = schema;
   this._schema = cloneDeep(this._originalSchema); // this is what can be munched on
   this._copiedReference = null;
 
-  $('#schema-alignment-statements-container').empty();
+  $('#schema-alignment-entity-edits-container').empty();
 
-  if (this._schema && this._schema.itemDocuments) {
-    for(var i = 0; i !== this._schema.itemDocuments.length; i++) {
-      this._addItem(this._schema.itemDocuments[i]);
+  if (this._schema && this._schema.entityEdits) {
+    for(let entityEdit of this._schema.entityEdits) {
+      let entityType = 'item'; // default, for backwards compatibility
+      if (entityEdit.type === 'wbitemeditexpr') {
+        entityType = 'item';	
+      } else if (entityEdit.type === 'wbmediainfoeditexpr') {
+	    entityType = 'mediainfo';
+      }
+      this._addEntity(entityType, entityEdit);
     }
   }
 };
@@ -327,9 +355,13 @@ SchemaAlignment._changesCleared = function() {
         .addClass('disabled');
 };
 
-SchemaAlignment._createDraggableColumn = function(name, reconciled) {
+SchemaAlignment._createDraggableColumn = function(name, reconciledSiteIRI) {
   var cell = $("<div></div>").addClass('wbs-draggable-column').text(name);
-  if (reconciled) {
+  cell.data({
+        'columnName': name,
+        'reconciledSiteIRI': reconciledSiteIRI
+  });
+  if (reconciledSiteIRI !== null) {
     cell.addClass('wbs-reconciled-column');
   } else {
     cell.addClass('wbs-unreconciled-column');
@@ -353,6 +385,32 @@ SchemaAlignment._makeDeleteButton = function (noText) {
   return button;
 };
 
+/************/
+/* ENTITIES */
+/************/
+
+SchemaAlignment._addEntity = function(entityType, json) {
+  if (entityType === 'item') {
+	SchemaAlignment._addItem(json);
+  } else if (entityType === 'mediainfo') {
+	SchemaAlignment._addMediaInfo(json);
+  } else {
+	console.error('unsupported entity type: '+entityType);
+  }
+}
+
+SchemaAlignment._entityToJSON = function (domElem) {
+  if (domElem.hasClass('wbs-item')) {
+	return SchemaAlignment._itemToJSON(domElem);
+  } else if (domElem.hasClass('wbs-mediainfo')) {
+	return SchemaAlignment._mediaInfoToJSON(domElem);
+  } else {
+	console.error('unsupported entity type');
+	return null;
+  }
+}
+
+
 /**************/
 /*** ITEMS ****/
 /**************/
@@ -367,21 +425,27 @@ SchemaAlignment._addItem = function(json) {
      nameDescs = json.nameDescs;
   }
 
-  var item = $('<div></div>').addClass('wbs-item');
-  $('#schema-alignment-statements-container').append(item);
+  var item = $('<div></div>')
+	.addClass('wbs-entity')
+	.addClass('wbs-item');
+  $('#schema-alignment-entity-edits-container').append(item);
   var deleteToolbar = $('<div></div>').addClass('wbs-toolbar')
         .attr('style', 'margin-top: 10px')
         .appendTo(item);
   var deleteButton = SchemaAlignment._makeDeleteButton()
         .appendTo(deleteToolbar)
-        .click(function(e) {
+        .on('click',function(e) {
      item.remove();
      SchemaAlignment._hasChanged();
      e.preventDefault();
   });
-  var inputContainer = $('<div></div>').addClass('wbs-item-input').appendTo(item);
-  SchemaAlignment._initField(inputContainer, "wikibase-item", subject);
-  var right = $('<div></div>').addClass('wbs-item-contents').appendTo(item);
+  var inputContainer = $('<div></div>').addClass('wbs-entity-input').appendTo(item);
+  // TODO temporary solution to pick another entity type than item
+  // depending on the Wikibase manifest. To be removed in favour of proper support
+  // for multiple entity types per Wikibase
+  let defaultEntityType = 'item';
+  SchemaAlignment._initField(inputContainer, "wikibase-"+defaultEntityType, subject);
+  var right = $('<div></div>').addClass('wbs-entity-contents').appendTo(item);
 
   // Terms
   $('<span></span>').addClass('wbs-namedesc-header')
@@ -391,7 +455,7 @@ SchemaAlignment._addItem = function(json) {
         .appendTo(right);
   var termToolbar = $('<div></div>').addClass('wbs-toolbar').appendTo(right);
   var addNamedescButton = $('<a></a>').addClass('wbs-add-namedesc')
-  .click(function(e) {
+  .on('click',function(e) {
      SchemaAlignment._addNameDesc(item, null);
      e.preventDefault();
   }).appendTo(termToolbar);
@@ -409,7 +473,7 @@ SchemaAlignment._addItem = function(json) {
         .appendTo(right);
   var statementToolbar = $('<div></div>').addClass('wbs-toolbar').appendTo(right);
   var addStatementButton = $('<a></a>').addClass('wbs-add-statement-group')
-        .click(function(e) {
+        .on('click',function(e) {
      SchemaAlignment._addStatementGroup(item, null);
      e.preventDefault();
   }).appendTo(statementToolbar);
@@ -447,12 +511,128 @@ SchemaAlignment._itemToJSON = function (item) {
            nameDescLst.push(nameDescJSON);
         }
     });
-    var inputContainer = item.find(".wbs-item-input").first();
+    var inputContainer = item.find(".wbs-entity-input").first();
     var subjectJSON = SchemaAlignment._inputContainerToJSON(inputContainer);
     if (subjectJSON !== null &&
         statementGroupLst.length === statementsDom.length &&
         nameDescLst.length === nameDescsDom.length) {
-      return {subject: subjectJSON,
+      return {
+	        type: 'wbitemeditexpr',
+	        subject: subjectJSON,
+            statementGroups: statementGroupLst,
+            nameDescs: nameDescLst}; 
+    } else {
+      return null;
+    }
+};
+
+/***********************
+ * MEDIA INFO ENTITIES *
+ ***********************/
+
+SchemaAlignment._addMediaInfo = function(json) {
+  var subject = null;
+  var statementGroups = null;
+  var nameDescs = null;
+  if (json) {
+     subject = json.subject;
+     statementGroups = json.statementGroups;
+     nameDescs = json.nameDescs;
+  }
+
+  var item = $('<div></div>').addClass('wbs-entity')
+	.addClass('wbs-mediainfo');
+  $('#schema-alignment-entity-edits-container').append(item);
+  var deleteToolbar = $('<div></div>').addClass('wbs-toolbar')
+        .attr('style', 'margin-top: 10px')
+        .appendTo(item);
+  var deleteButton = SchemaAlignment._makeDeleteButton()
+        .appendTo(deleteToolbar)
+        .on('click',function(e) {
+     item.remove();
+     SchemaAlignment._hasChanged();
+     e.preventDefault();
+  });
+  var inputContainer = $('<div></div>').addClass('wbs-entity-input').appendTo(item);
+  // TODO temporary solution to pick another entity type than item
+  // depending on the Wikibase manifest. To be removed in favour of proper support
+  // for multiple entity types per Wikibase
+  let defaultEntityType = 'mediainfo';
+  SchemaAlignment._initField(inputContainer, "wikibase-"+defaultEntityType, subject);
+  var right = $('<div></div>').addClass('wbs-entity-contents').appendTo(item);
+
+  // Captions
+  $('<span></span>').addClass('wbs-namedesc-header')
+       .text($.i18n('wikibase-schema/captions-header')).appendTo(right);
+  $('<div></div>').addClass('wbs-namedesc-container')
+        .attr('data-emptyplaceholder', $.i18n('wikibase-schema/empty-terms'))
+        .appendTo(right);
+  var termToolbar = $('<div></div>').addClass('wbs-toolbar').appendTo(right);
+  var addNamedescButton = $('<a></a>').addClass('wbs-add-namedesc')
+  .on('click',function(e) {
+     SchemaAlignment._addNameDesc(item, {name_type: 'LABEL_IF_NEW', value: null});
+     e.preventDefault();
+  }).appendTo(termToolbar);
+  SchemaAlignment._plusButton(
+         $.i18n('wikibase-schema/add-caption'), addNamedescButton);
+
+  // Clear the float
+  $('<div></div>').attr('style', 'clear: right').appendTo(right);
+
+  // Statements
+  $('<div></div>').addClass('wbs-statements-header')
+        .text($.i18n('wikibase-schema/statements-header')).appendTo(right);
+  $('<div></div>').addClass('wbs-statement-group-container')
+        .attr('data-emptyplaceholder', $.i18n('wikibase-schema/empty-statements'))
+        .appendTo(right);
+  var statementToolbar = $('<div></div>').addClass('wbs-toolbar').appendTo(right);
+  var addStatementButton = $('<a></a>').addClass('wbs-add-statement-group')
+        .on('click',function(e) {
+     SchemaAlignment._addStatementGroup(item, null);
+     e.preventDefault();
+  }).appendTo(statementToolbar);
+
+  SchemaAlignment._plusButton(
+         $.i18n('wikibase-schema/add-statement'), addStatementButton);
+   
+  if (statementGroups) {
+     for(var i = 0; i != statementGroups.length; i++) {
+        SchemaAlignment._addStatementGroup(item, statementGroups[i]);
+     }
+  }
+  
+  if (nameDescs) {
+     for(var i = 0; i != nameDescs.length; i++) {
+        SchemaAlignment._addNameDesc(item, nameDescs[i]);
+     }
+  }
+};
+
+SchemaAlignment._mediaInfoToJSON = function (mediainfo) {
+    var statementGroupLst = new Array();
+    var statementsDom = mediainfo.find('.wbs-statement-group');
+    statementsDom.each(function () {
+        var statementGroupJSON = SchemaAlignment._statementGroupToJSON($(this));
+        if (statementGroupJSON !== null) {
+          statementGroupLst.push(statementGroupJSON);
+        }
+    });
+    var nameDescLst = new Array();
+    var nameDescsDom = mediainfo.find('.wbs-namedesc');
+    nameDescsDom.each(function () {
+        var nameDescJSON = SchemaAlignment._nameDescToJSON($(this));
+        if (nameDescJSON !== null) {
+           nameDescLst.push(nameDescJSON);
+        }
+    });
+    var inputContainer = mediainfo.find(".wbs-entity-input").first();
+    var subjectJSON = SchemaAlignment._inputContainerToJSON(inputContainer);
+    if (subjectJSON !== null &&
+        statementGroupLst.length === statementsDom.length &&
+        nameDescLst.length === nameDescsDom.length) {
+      return {
+	        type: "wbmediainfoeditexpr",
+	        subject: subjectJSON,
             statementGroups: statementGroupLst,
             nameDescs: nameDescLst}; 
     } else {
@@ -493,7 +673,7 @@ SchemaAlignment._addNameDesc = function(item, json) {
   type_input.val(term_type);
 
   var toolbar = $('<div></div>').addClass('wbs-toolbar').appendTo(namedesc);
-  SchemaAlignment._makeDeleteButton().click(function(e) {
+  SchemaAlignment._makeDeleteButton().on('click',function(e) {
      namedesc.remove();
      SchemaAlignment._hasChanged();
      e.preventDefault();
@@ -562,7 +742,7 @@ SchemaAlignment._addStatementGroup = function(item, json) {
   var statementContainer = $('<div></div>').addClass('wbs-statement-container').appendTo(right);
   SchemaAlignment._initPropertyField(inputContainer, statementContainer, property);
   var toolbar = $('<div></div>').addClass('wbs-toolbar').appendTo(right);
-  var addValueButton = $('<a></a>').addClass('wbs-add-statement').click(function(e) {
+  var addValueButton = $('<a></a>').addClass('wbs-add-statement').on('click',function(e) {
      var datatype = inputContainer.data("jsonValue").datatype;
      SchemaAlignment._addStatement(statementContainer, datatype, null);
      e.preventDefault();
@@ -571,7 +751,7 @@ SchemaAlignment._addStatementGroup = function(item, json) {
   var removeButton = SchemaAlignment._makeDeleteButton()
         .addClass('wbs-remove-statement-group')
         .appendTo(toolbar)
-        .click(function(e) {
+        .on('click',function(e) {
      statementGroup.remove();
      e.preventDefault();
   });
@@ -585,7 +765,7 @@ SchemaAlignment._addStatementGroup = function(item, json) {
         removeButton.hide();
      }
   } else {
-     inputContainer.find('input').focus();
+     inputContainer.find('input').trigger('focus');
   }
      
 };
@@ -617,10 +797,14 @@ SchemaAlignment._addStatement = function(container, datatype, json) {
   var qualifiers = null;
   var references = null;
   var value = null;
+  var editingMode = StatementConfigurationDialog.defaultMode;
+  var mergingStrategy = StatementConfigurationDialog.defaultStrategy;
   if (json) {
     qualifiers = json.qualifiers;
     references = json.references;
     value = json.value;
+    editingMode = json.mode || 'add_or_merge';
+    mergingStrategy = json.mergingStrategy || {'type':'qualifiers','valueMatcher':{'type':'strict'}};
   }
  
   var statement = $('<div></div>').addClass('wbs-statement');
@@ -630,22 +814,43 @@ SchemaAlignment._addStatement = function(container, datatype, json) {
   // If we are in a mainsnak...
   // (see https://www.mediawiki.org/wiki/Wikibase/DataModel#Snaks)
   if (container.parents('.wbs-statement').length == 0) {
+    inputContainer.children().first().addClass('wbs-mainsnak-input');
+    statement
+            .data('jsonMode', editingMode)
+            .data('jsonMergingStrategy', JSON.stringify(mergingStrategy));
+    inputContainer.append(
+       $('<span></span>')
+        .addClass('wbs-value-placeholder') 
+        .text($.i18n('wikibase-preview/delete-all-existing-statements')));
     // add delete button
     var toolbar1 = $('<div></div>').addClass('wbs-toolbar').appendTo(statement);
-    SchemaAlignment._makeDeleteButton().click(function(e) {
+    SchemaAlignment._makeDeleteButton().on('click',function(e) {
         SchemaAlignment._removeStatement(statement);
         e.preventDefault();
     }).appendTo(toolbar1);
+    // add configure button
+    var configureButton = $('<div></div>').addClass('wbs-configure');
+    $('<span></span>').addClass('wbs-icon').appendTo(configureButton);
+    $('<span></span>').text($.i18n('wikibase-schema/configure-statement')).appendTo(configureButton);
+    configureButton.appendTo(toolbar1);
+    configureButton.on('click',function(e) {
+        SchemaAlignment._openStatementConfigurationDialog(statement);
+        e.preventDefault();
+    });
 
     // add rank
-    var rank = $('<div></div>').addClass('wbs-rank-selector-icon').prependTo(inputContainer);
+    var rank = $('<div></div>')
+        .addClass('wbs-rank-selector-icon')
+        .addClass('wbs-mainsnak-input')
+        .prependTo(inputContainer);
 
     // add qualifiers...
-    var right = $('<div></div>').addClass('wbs-right').appendTo(statement);
+    var qualifiersSection = $('<div></div>').addClass('wbs-qualifiers-section').appendTo(statement);
+    var right = $('<div></div>').addClass('wbs-right').appendTo(qualifiersSection);
     var qualifierContainer = $('<div></div>').addClass('wbs-qualifier-container').appendTo(right);
     var toolbar2 = $('<div></div>').addClass('wbs-toolbar').appendTo(right);
     var addQualifierButton = $('<a></a>').addClass('wbs-add-qualifier')
-        .click(function(e) {
+        .on('click',function(e) {
         SchemaAlignment._addQualifier(qualifierContainer, null);
         e.preventDefault();
     }).appendTo(toolbar2);
@@ -659,12 +864,13 @@ SchemaAlignment._addStatement = function(container, datatype, json) {
 
     // and references
     $('<div></div>').attr('style', 'clear: right').appendTo(statement);
-    var referencesToggleContainer = $('<div></div>').addClass('wbs-references-toggle').appendTo(statement);
+    var referencesSection = $('<div></div>').addClass('wbs-references-section').appendTo(statement);
+    var referencesToggleContainer = $('<div></div>').addClass('wbs-references-toggle').appendTo(referencesSection);
     var triangle = $('<div></div>').addClass('triangle-icon').addClass('pointing-right').appendTo(referencesToggleContainer);
     var referencesToggle = $('<a></a>').appendTo(referencesToggleContainer);
-    right = $('<div></div>').addClass('wbs-right').appendTo(statement);
+    right = $('<div></div>').addClass('wbs-right').appendTo(referencesSection);
     var referenceContainer = $('<div></div>').addClass('wbs-reference-container').appendTo(right);
-    referencesToggleContainer.click(function(e) {
+    referencesToggleContainer.on('click',function(e) {
         triangle.toggleClass('pointing-down');
         triangle.toggleClass('pointing-right');
         referenceContainer.toggle(100);
@@ -674,7 +880,7 @@ SchemaAlignment._addStatement = function(container, datatype, json) {
     var right2 = $('<div></div>').addClass('wbs-right').appendTo(right);
     var toolbar3 = $('<div></div>').addClass('wbs-toolbar').appendTo(right2);
     var addReferenceButton = $('<a></a>').addClass('wbs-add-reference')
-        .click(function(e) {
+        .on('click',function(e) {
         referenceContainer.show();
         SchemaAlignment._addReference(referenceContainer, null);
         SchemaAlignment._updateReferencesNumber(referenceContainer);
@@ -694,7 +900,7 @@ SchemaAlignment._addStatement = function(container, datatype, json) {
         .addClass('wbs-paste-reference-button')
         .text($.i18n('wikibase-schema/paste-reference'))
         .appendTo(referencePaste)
-        .click(function(e) {
+        .on('click',function(e) {
         if (SchemaAlignment._copiedReference !== null) {
            SchemaAlignment._addReference(referenceContainer, SchemaAlignment._copiedReference);
            SchemaAlignment._updateReferencesNumber(referenceContainer);
@@ -711,14 +917,31 @@ SchemaAlignment._addStatement = function(container, datatype, json) {
         }
     }
     SchemaAlignment._updateReferencesNumber(referenceContainer);
+    SchemaAlignment._updateStatementFromMergingStrategy(statement);
   }
+
   container.append(statement);
 };
 
+// further tweaks to the statement UI if the statement is to be deleted
+SchemaAlignment._updateStatementFromMergingStrategy = function (statement) {
+  var mode = statement.data('jsonMode');
+  var strategyType = JSON.parse(statement.data('jsonMergingStrategy'))['type'];
+  var references = statement.find(".wbs-references-section").first();
+  var qualifiers = statement.find(".wbs-qualifiers-section").first();
+  statement.removeClass();
+  statement.addClass('wbs-statement');
+  statement.addClass('wbs-statement-mode-'+mode);
+  statement.addClass('wbs-statement-strategy-'+strategyType);
+};
+
 SchemaAlignment._statementToJSON = function (statement) {
     var inputContainer = statement.find(".wbs-target-input").first();
     var qualifiersList = new Array();
     var referencesList = new Array();
+    var editingMode = statement.data('jsonMode');
+    var mergingStrategy = JSON.parse(statement.data('jsonMergingStrategy'));
+    var mergingStrategyType = mergingStrategy['type'];
     var qualifiersDom = statement.find('.wbs-qualifier-container').first().children();
     qualifiersDom.each(function () {
         var qualifierJSON = SchemaAlignment._qualifierToJSON($(this));
@@ -727,20 +950,27 @@ SchemaAlignment._statementToJSON = function (statement) {
         }
     });
     var referencesDom = statement.find('.wbs-reference-container').first().children();
-    referencesDom.each(function () {
-        var referenceJSON = SchemaAlignment._referenceToJSON($(this));
-        if (referenceJSON !== null) {
-          referencesList.push(referenceJSON);
-        }
-    });
-    var valueJSON = SchemaAlignment._inputContainerToJSON(inputContainer);
-    if (referencesList.length === referencesDom.length &&
-        qualifiersList.length === qualifiersDom.length &&
-        valueJSON !== null) {
+    if (editingMode !== 'delete') {
+        referencesDom.each(function () {
+            var referenceJSON = SchemaAlignment._referenceToJSON($(this));
+            if (referenceJSON !== null) {
+            referencesList.push(referenceJSON);
+            }
+        });
+    }
+    var valueJSON = null;
+    if (!(editingMode === 'delete' && mergingStrategyType === 'property')) {
+      valueJSON = SchemaAlignment._inputContainerToJSON(inputContainer);
+    }
+    if ((editingMode === 'delete' || referencesList.length === referencesDom.length) &&
+        ((editingMode === 'delete' && (mergingStrategyType === 'snak' || mergingStrategy === 'property')) || qualifiersList.length === qualifiersDom.length) &&
+        ((editingMode === 'delete' && mergingStrategyType === 'property') || valueJSON !== null)) {
       return {
         value: valueJSON,
         qualifiers: qualifiersList,
         references: referencesList,
+        mode: editingMode,
+        mergingStrategy: mergingStrategy
       };
     } else {
       return null;
@@ -765,7 +995,7 @@ SchemaAlignment._addQualifier = function(container, json) {
   var right = $('<div></div>').addClass('wbs-right').appendTo(qualifier);
   var deleteButton = SchemaAlignment._makeDeleteButton()
             .addClass('wbs-remove-statement-group')
-            .appendTo(toolbar1).click(function(e) {
+            .appendTo(toolbar1).on('click',function(e) {
     qualifier.remove();
     SchemaAlignment._hasChanged();
     e.preventDefault();
@@ -775,7 +1005,7 @@ SchemaAlignment._addQualifier = function(container, json) {
   if (value && property) {
     SchemaAlignment._addStatement(statementContainer, property.datatype, {value:value});
   } else {
-    inputContainer.find('input').focus();
+    inputContainer.find('input').trigger('focus');
   }
 };
 
@@ -812,7 +1042,7 @@ SchemaAlignment._addReference = function(container, json) {
         .addClass('wbs-copy-reference-button')
         .text($.i18n('wikibase-schema/copy-reference'))
         .appendTo(referenceCopy)
-        .click(function(e) {
+        .on('click',function(e) {
      if (SchemaAlignment._copyReference(reference)) {
        $(this).text($.i18n('wikibase-schema/reference-copied'))
               .parent().addClass('wbs-copied-reference');
@@ -821,7 +1051,7 @@ SchemaAlignment._addReference = function(container, json) {
      e.preventDefault();
   });
   var toolbarRef = $('<div></div>').addClass('wbs-toolbar').appendTo(referenceHeader);
-  SchemaAlignment._makeDeleteButton().click(function(e) {
+  SchemaAlignment._makeDeleteButton().on('click',function(e) {
      reference.remove();
      SchemaAlignment._updateReferencesNumber(container);
      SchemaAlignment._hasChanged();
@@ -831,7 +1061,7 @@ SchemaAlignment._addReference = function(container, json) {
   var qualifierContainer = $('<div></div>').addClass('wbs-qualifier-container').appendTo(right);
   var toolbar2 = $('<div></div>').addClass('wbs-toolbar').appendTo(right);
   var addSnakButton = $('<a></a>').addClass('wbs-add-qualifier')
-        .click(function(e) {
+        .on('click',function(e) {
       SchemaAlignment._addQualifier(qualifierContainer, null);
       e.preventDefault();
   }).appendTo(toolbar2);
@@ -908,29 +1138,30 @@ SchemaAlignment._initPropertyField = function(inputContainer, targetContainer, i
   var input = $('<input></input>').appendTo(inputContainer);
   input.attr("placeholder", $.i18n('wikibase-schema/property-placeholder'));
 
-  if (this._reconService !== null) {
-    var endpoint = this._reconService.suggest.property;
-    var suggestConfig = $.extend({}, endpoint);
-    suggestConfig.key = null;
-    suggestConfig.query_param_name = "prefix";
-
-    input.suggestP(suggestConfig).bind("fb-select", function(evt, data) {
-        // Fetch the type of this property and add the appropriate target value type
-        SchemaAlignment._getPropertyType(data.id, function(datatype) {
-          inputContainer.data("jsonValue", {
-            type : "wbpropconstant",
-            pid : data.id,
-            label: data.name,
-            datatype: datatype,
-          });
-          SchemaAlignment._addStatement(targetContainer, datatype, null);
-          var addValueButtons = targetContainer.parent().find('.wbs-add-statement');
-          var removeGroupButton = targetContainer.parent().find('.wbs-remove-statement-group');
-          removeGroupButton.hide();
-          addValueButtons.show();
+  var endpoint = WikibaseManager.getSelectedWikibaseApiForEntityType('property');
+  var suggestConfig = {
+    mediawiki_endpoint: endpoint,
+    entity_type: 'property',
+    language: $.i18n("core-recon/wd-recon-lang"),
+    view_url: WikibaseManager.getSelectedWikibaseSiteIriForEntityType('property')+'{{id}}'
+  };
+  
+  input.suggestWikibase(suggestConfig).on("fb-select", function(evt, data) {
+      SchemaAlignment._getPropertyType(data.id, function(datatype) {
+        inputContainer.data("jsonValue", {
+          type : "wbpropconstant",
+          pid : data.id,
+          label: data.name,
+          datatype: datatype,
         });
-        SchemaAlignment._hasChanged();
-    }).bind("fb-textchange", function(evt, data) {
+        SchemaAlignment._addStatement(targetContainer, datatype, null);
+        var addValueButtons = targetContainer.parent().find('.wbs-add-statement');
+        var removeGroupButton = targetContainer.parent().find('.wbs-remove-statement-group');
+        removeGroupButton.hide();
+        addValueButtons.show();
+      });
+      SchemaAlignment._hasChanged();
+    }).on("fb-textchange", function(evt, data) {
         inputContainer.data("jsonValue", null);
         targetContainer.find('.wbs-statement').remove();
         var addValueButtons = targetContainer.parent().find('.wbs-add-statement');
@@ -938,9 +1169,8 @@ SchemaAlignment._initPropertyField = function(inputContainer, targetContainer, i
         addValueButtons.hide();
         removeGroupButton.show();
     });
-   // adds tweaks to display the validation status more clearly, like in Wikidata
-   fixSuggestInput(input);
-  }
+  // adds tweaks to display the validation status more clearly, like in Wikidata
+  fixSuggestInput(input);
 
   // Init with the provided initial value.
   if (initialValue) {
@@ -960,52 +1190,34 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
     changedCallback = SchemaAlignment._hasChanged;
   }
 
-  if (this._reconService !== null && (mode === "wikibase-item" || mode === "unit")) {
-    if (mode === "wikibase-item") {
-        input.attr("placeholder", $.i18n('wikibase-schema/item-or-reconciled-column'));
+  // the mode for Wikibase entities has the form "wikibase-{entitytype}", such as "wikibase-item" or "wikibase-property"
+  if (this._reconService !== null && (mode.startsWith("wikibase-") || mode === "unit")) {
+    var entityType = null;
+    if (mode.startsWith("wikibase-")) {
+        input.attr("placeholder", $.i18n('wikibase-schema/entity-or-reconciled-column'));
+	entityType = mode.slice("wikibase-".length);
     } else {
         input.attr("placeholder", $.i18n('wikibase-schema/unit'));
+	entityType = "item";
     }
-    var endpoint = null;
-    endpoint = this._reconService.suggest.entity;
-    var suggestConfig = $.extend({}, endpoint);
-    suggestConfig.key = null;
-    suggestConfig.query_param_name = "prefix";
-    if ('view' in this._reconService && 'url' in this._reconService.view && !('view_url' in endpoint)) {
-       suggestConfig.view_url = this._reconService.view.url;
-    }
-
-
-    input.suggest(suggestConfig).bind("fb-select", function(evt, data) {
+    var endpoint = WikibaseManager.getSelectedWikibaseApiForEntityType(entityType);
+    var suggestConfig = {
+      mediawiki_endpoint: endpoint,
+      entity_type: entityType,
+      language: $.i18n("core-recon/wd-recon-lang"),
+      view_url: WikibaseManager.getSelectedWikibaseSiteIriForEntityType(entityType)+'{{id}'
+    };
+    
+    input.suggestWikibase(suggestConfig).on("fb-select", function(evt, data) {
         inputContainer.data("jsonValue", {
-            type : "wbitemconstant",
-            qid : data.id,
+            type : "wbentityidvalueconstant",
+            id : data.id,
             label: data.name,
         });
         changedCallback();
     });
     // adds tweaks to display the validation status more clearly, like in Wikidata
     fixSuggestInput(input);
-
-  } else if (this._reconService !== null && mode === "wikibase-property") {
-    var endpoint = null;
-    endpoint = this._reconService.suggest.property;
-    var suggestConfig = $.extend({}, endpoint);
-    suggestConfig.key = null;
-    suggestConfig.query_param_name = "prefix";
-
-    input.suggestP(suggestConfig).bind("fb-select", function(evt, data) {
-        inputContainer.data("jsonValue", {
-            type : "wbpropconstant",
-            pid : data.id,
-            label: data.name,
-            datatype: "not-important",
-        });
-        changedCallback();
-    });
-    // adds tweaks to display the validation status more clearly, like in Wikidata
-    fixSuggestInput(input);
-
   } else if (mode === "time") {
      input.attr("placeholder", "YYYY(-MM(-DD))");
      var propagateValue = function(val) {
@@ -1016,7 +1228,7 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
         });
     };
     propagateValue("");
-    input.change(function() {
+    input.on('change',function() {
       propagateValue($(this).val());
       changedCallback();
     });
@@ -1032,7 +1244,7 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
         });
     };
     propagateValue("");
-    input.change(function() {
+    input.on('change',function() {
       propagateValue($(this).val());
       changedCallback();
     });
@@ -1041,7 +1253,7 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
    } else if (mode === "language") {
      input.attr("placeholder", "lang");
      input.addClass("wbs-language-input");
-     input.langsuggest().bind("fb-select", function(evt, data) {
+     input.langsuggest().on("fb-select", function(evt, data) {
         inputContainer.data("jsonValue", {
             type: "wblanguageconstant",
             id: data.id,
@@ -1119,7 +1331,7 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
         });
     };
     propagateValue("");
-    input.change(function() {
+    input.on('change',function() {
       propagateValue($(this).val());
       changedCallback();
     });
@@ -1176,9 +1388,15 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
   // Make it droppable
   var acceptClass = ".wbs-draggable-column";
   var wbVariableType = "wbstringvariable";
-  if (mode === "wikibase-item" || mode === "unit") {
+  var entityType = null;
+  if (mode.startsWith("wikibase-") || mode === "unit") {
       acceptClass = ".wbs-reconciled-column";
-      wbVariableType = "wbitemvariable";
+      wbVariableType = "wbentityvariable";
+      if (mode === "unit") {
+        entityType = "item";
+      } else {
+        entityType = mode.slice("wikibase-".length);
+      }
   } else if (mode === "time") {
       wbVariableType = "wbdatevariable";
   } else if (mode === "globe-coordinate") {
@@ -1194,6 +1412,16 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
         accept: acceptClass,
     }).on("drop", function (evt, ui) {
         var column = ui.draggable.clone();
+        if (entityType !== null) {
+          // check that the siteIRI of the reconciled column matches
+          // the expected one.
+          var expectedSiteIRI = WikibaseManager.getSelectedWikibaseSiteIriForEntityType(entityType);
+          var actualSiteIRI = ui.draggable.data('reconciledSiteIRI');
+          if (actualSiteIRI !== expectedSiteIRI) {
+            alert($.i18n('wikibase-schema/incompatible-site-iri-reconciled-column', actualSiteIRI, expectedSiteIRI));
+            return false;
+          }
+        }
         acceptDraggableColumn(column);
         inputContainer.data("jsonValue", {
             type : wbVariableType,
@@ -1210,10 +1438,12 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
 
   // Init with the provided initial value.
   if (initialValue) {
-     if (initialValue.type === "wbitemconstant" || initialValue.type === "wbpropconstant") {
+     if (initialValue.type === "wbentityidvalueconstant" ||
+        /* item for backwards-compatibility purposes */
+        initialValue.type === "wbitemconstant" || initialValue.type === "wbpropconstant") {
         input.val(initialValue.label);
         input.addClass("wbs-validated-input");
-     } else if (initialValue.type == "wbitemvariable") {
+     } else if (initialValue.type == "wbentityvariable") {
         var cell = SchemaAlignment._createDraggableColumn(initialValue.columnName, true);
         acceptDraggableColumn(cell);
      } else if (initialValue.type === "wbstringconstant" ||
@@ -1235,9 +1465,9 @@ SchemaAlignment._initField = function(inputContainer, mode, initialValue, change
 };
 
 SchemaAlignment.setupStringInputValidation = function(input, regex) {
-  input.focus(function() {
+  input.on('focus',function() {
     input.removeClass('wbs-unvalidated-input');
-  }).blur(function() {
+  }).on('blur',function() {
     var currentValue = input.val();
     if (regex.test(currentValue)) {
        input.addClass('wbs-validated-input');
@@ -1266,19 +1496,24 @@ SchemaAlignment._removeStatement = function(statement) {
   SchemaAlignment._hasChanged();
 };
 
+SchemaAlignment._openStatementConfigurationDialog = function(statement) {
+  StatementConfigurationDialog.launch(statement);
+};
+
 SchemaAlignment.getJSON = function() {
   var list = [];
-  var itemsDom = $('#schema-alignment-statements-container .wbs-item');
-  itemsDom.each(function () {
-     var itemJSON = SchemaAlignment._itemToJSON($(this));
-     if (itemJSON !== null) {
-        list.push(itemJSON);
+  var entitiesDom = $('#schema-alignment-entity-edits-container .wbs-entity');
+  entitiesDom.each(function () {
+     var entityJSON = SchemaAlignment._entityToJSON($(this));
+     if (entityJSON !== null) {
+        list.push(entityJSON);
      }
   });
-  if (list.length === itemsDom.length) {
+  if (list.length === entitiesDom.length) {
     return {
-        itemDocuments: list,
+        entityEdits: list,
         siteIri: WikibaseManager.getSelectedWikibaseSiteIri(),
+        entityTypeSiteIRI: Object.fromEntries(WikibaseManager.getSelectedWikibaseAvailableEntityTypes().map(et => [et, WikibaseManager.getSelectedWikibaseSiteIriForEntityType(et)])),
         mediaWikiApiEndpoint: WikibaseManager.getSelectedWikibaseApi()
     };
   } else {
