@@ -3,6 +3,9 @@ package org.openrefine.wikidata.manifests;
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.ObjectMapper;
+
+import java.io.IOException;
+
 import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -33,6 +36,12 @@ public final class ManifestParser {
         // support only v1.x for now
         if ("1".equals(majorVersion)) {
             return new ManifestV1(root);
+        } else if ("2".equals(majorVersion)) {
+        	try {
+				return new ManifestV2(root);
+			} catch (IOException e) {
+				throw new ManifestException("invalid manifest format: " + e.getMessage());
+			}
         } else {
             throw new ManifestException("unsupported manifest version: " + version);
         }
