@@ -1,17 +1,19 @@
 package org.openrefine.wikidata.qa.scrutinizers;
 
-import org.openrefine.wikidata.updates.ItemUpdate;
-import org.wikidata.wdtk.datamodel.interfaces.MonolingualTextValue;
-
 import java.util.Set;
 
+import org.openrefine.wikidata.updates.ItemEdit;
+import org.openrefine.wikidata.updates.LabeledStatementEntityEdit;
+import org.openrefine.wikidata.updates.MediaInfoEdit;
+import org.wikidata.wdtk.datamodel.interfaces.MonolingualTextValue;
+
 /**
  * @author Lu Liu
  */
 public abstract class DescriptionScrutinizer extends EditScrutinizer {
 
     @Override
-    public void scrutinize(ItemUpdate update) {
+    public void scrutinize(ItemEdit update) {
         Set<MonolingualTextValue> descriptions = update.getDescriptions();
         descriptions.addAll(update.getDescriptionsIfNew()); // merge
         for (MonolingualTextValue description : descriptions) {
@@ -27,7 +29,12 @@ public abstract class DescriptionScrutinizer extends EditScrutinizer {
             scrutinize(update, descText, description.getLanguageCode());
         }
     }
+    
+    @Override
+    public void scrutinize(MediaInfoEdit update) {
+    	// no descriptions to scrutinize: do nothing
+    }
 
-    public abstract void scrutinize(ItemUpdate update, String descText, String lang);
+    public abstract void scrutinize(LabeledStatementEntityEdit update, String descText, String lang);
 
 }
