@@ -26,5 +26,15 @@ package org.openrefine.wikidata.updates.scheduler;
 public class ImpossibleSchedulingException extends Exception {
 
     private static final long serialVersionUID = 6621563898380564148L;
+    
+    private final String message;
+    
+    public ImpossibleSchedulingException(String message) {
+    	this.message = message;
+    }
+    
+    public String getMessage() {
+    	return message;
+    }
 
 }
