@@ -1,3 +1,4 @@
+
 package org.openrefine.wikidata.exporters;
 
 import java.io.IOException;
@@ -12,18 +13,20 @@ import com.google.refine.model.Project;
 import com.google.refine.util.TestUtils;
 
 public class SchemaExporterTest extends WikidataRefineTest {
-	
-	private SchemaExporter exporter = new SchemaExporter();
-	
+
+    private SchemaExporter exporter = new SchemaExporter();
+
     @Test
     public void testNoSchema()
             throws IOException {
+        // TODO instead of returning an empty (and invalid) schema, we should just return an error
         Project project = this.createCSVProject("a,b\nc,d");
         Engine engine = new Engine(project);
         StringWriter writer = new StringWriter();
         Properties properties = new Properties();
         exporter.export(project, properties, engine, writer);
-        TestUtils.assertEqualAsJson("{\"itemDocuments\":[],\"siteIri\":null,\"mediaWikiApiEndpoint\":null}", writer.toString());
+        TestUtils.assertEqualAsJson("{\"entityEdits\":[],\"siteIri\":null,\"mediaWikiApiEndpoint\":null,\"entityTypeSiteIRI\":{}}",
+                writer.toString());
     }
 
 }
