@@ -33,7 +33,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 package com.google.refine.importers;
 
-
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.testng.Assert.assertTrue;
@@ -68,74 +67,75 @@ import com.fasterxml.jackson.databind.node.ArrayNode;
 import com.google.refine.util.ParsingUtilities;
 
 public class ExcelImporterTests extends ImporterTest {
-    
+
     private static final double EPSILON = 0.0000001;
     private static final int SHEETS = 3;
     private static final int ROWS = 5;
     private static final int COLUMNS = 6;
-    
-    //private static final File xlsxFile = createSpreadsheet(true);
+
+    // private static final File xlsxFile = createSpreadsheet(true);
     private static final File xlsFile = createSpreadsheet(false);
     private static final File xlsxFile = createSpreadsheet(true);
 
     private static final File xlsFileWithMultiSheets = createSheetsWithDifferentColumns(false);
     private static final File xlsxFileWithMultiSheets = createSheetsWithDifferentColumns(true);
-    
+
     @Override
     @BeforeTest
     public void init() {
         logger = LoggerFactory.getLogger(this.getClass());
     }
 
-    //System Under Test
+    // System Under Test
     ExcelImporter SUT = null;
 
     @Override
     @BeforeMethod
-    public void setUp(){
+    public void setUp() {
         super.setUp();
         SUT = new ExcelImporter();
     }
 
     @Override
     @AfterMethod
-    public void tearDown(){
+    public void tearDown() {
         SUT = null;
         super.tearDown();
     }
-    
-    //---------------------read tests------------------------
+
+    // ---------------------read tests------------------------
     @Test
-    public void readXls() throws FileNotFoundException, IOException{
+    public void readXls() throws FileNotFoundException, IOException {
 
         ArrayNode sheets = ParsingUtilities.mapper.createArrayNode();
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
         whenGetArrayOption("sheets", options, sheets);
-        
+
         whenGetIntegerOption("ignoreLines", options, 0);
         whenGetIntegerOption("headerLines", options, 0);
         whenGetIntegerOption("skipDataLines", options, 0);
         whenGetIntegerOption("limit", options, -1);
-        whenGetBooleanOption("storeBlankCellsAsNulls",options,true);
+        whenGetBooleanOption("storeBlankCellsAsNulls", options, true);
 
         InputStream stream = new FileInputStream(xlsFile);
-        
+
         try {
             parseOneFile(SUT, stream);
         } catch (Exception e) {
             Assert.fail(e.getMessage());
         }
-        
+
         Assert.assertEquals(project.rows.size(), ROWS);
         Assert.assertEquals(project.rows.get(1).cells.size(), COLUMNS);
-        Assert.assertEquals(((Number)project.rows.get(1).getCellValue(0)).doubleValue(),1.1, EPSILON);
-        Assert.assertEquals(((Number)project.rows.get(2).getCellValue(0)).doubleValue(),2.2, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(1).getCellValue(0)).doubleValue(), 1.1, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(2).getCellValue(0)).doubleValue(), 2.2, EPSILON);
 
-        Assert.assertFalse((Boolean)project.rows.get(1).getCellValue(1));
-        Assert.assertTrue((Boolean)project.rows.get(2).getCellValue(1));
-        
-        Assert.assertEquals((String)project.rows.get(1).getCellValue(4)," Row 1 Col 5");
-        Assert.assertNull((String)project.rows.get(1).getCellValue(5));
+        Assert.assertFalse((Boolean) project.rows.get(1).getCellValue(1));
+        Assert.assertTrue((Boolean) project.rows.get(2).getCellValue(1));
+
+        Assert.assertEquals((String) project.rows.get(1).getCellValue(4), " Row 1 Col 5");
+        Assert.assertNull((String) project.rows.get(1).getCellValue(5));
 
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(2))); // Calendar
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(3))); // Date
@@ -148,39 +148,40 @@ public class ExcelImporterTests extends ImporterTest {
     }
 
     @Test
-    public void readXlsx() throws FileNotFoundException, IOException{
+    public void readXlsx() throws FileNotFoundException, IOException {
 
         ArrayNode sheets = ParsingUtilities.mapper.createArrayNode();
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
         whenGetArrayOption("sheets", options, sheets);
-        
+
         whenGetIntegerOption("ignoreLines", options, 0);
         whenGetIntegerOption("headerLines", options, 0);
         whenGetIntegerOption("skipDataLines", options, 0);
         whenGetIntegerOption("limit", options, -1);
-        whenGetBooleanOption("storeBlankCellsAsNulls",options,true);
-        
+        whenGetBooleanOption("storeBlankCellsAsNulls", options, true);
+
         InputStream stream = new FileInputStream(xlsxFile);
-        
+
         try {
             parseOneFile(SUT, stream);
         } catch (Exception e) {
             Assert.fail(e.getMessage());
         }
-        
+
         Assert.assertEquals(project.rows.size(), ROWS);
         Assert.assertEquals(project.rows.get(1).cells.size(), COLUMNS);
-        Assert.assertEquals(((Number)project.rows.get(1).getCellValue(0)).doubleValue(),1.1, EPSILON);
-        Assert.assertEquals(((Number)project.rows.get(2).getCellValue(0)).doubleValue(),2.2, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(1).getCellValue(0)).doubleValue(), 1.1, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(2).getCellValue(0)).doubleValue(), 2.2, EPSILON);
 
-        Assert.assertFalse((Boolean)project.rows.get(1).getCellValue(1));
-        Assert.assertTrue((Boolean)project.rows.get(2).getCellValue(1));
+        Assert.assertFalse((Boolean) project.rows.get(1).getCellValue(1));
+        Assert.assertTrue((Boolean) project.rows.get(2).getCellValue(1));
 
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(2))); // Calendar
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(3))); // Date
 
-        Assert.assertEquals((String)project.rows.get(1).getCellValue(4)," Row 1 Col 5");
-        Assert.assertNull((String)project.rows.get(1).getCellValue(5));
+        Assert.assertEquals((String) project.rows.get(1).getCellValue(4), " Row 1 Col 5");
+        Assert.assertNull((String) project.rows.get(1).getCellValue(5));
 
         verify(options, times(1)).get("ignoreLines");
         verify(options, times(1)).get("headerLines");
@@ -190,7 +191,7 @@ public class ExcelImporterTests extends ImporterTest {
     }
 
     @Test
-    public void readExcel95() throws FileNotFoundException, IOException{
+    public void readExcel95() throws FileNotFoundException, IOException {
 
         InputStream stream = ClassLoader.getSystemResourceAsStream("excel95.xls");
 
@@ -201,11 +202,12 @@ public class ExcelImporterTests extends ImporterTest {
             Assert.fail(e.getMessage());
         }
     }
-    
+
     @Test
     public void readExcelDates() throws FileNotFoundException, IOException {
         ArrayNode sheets = ParsingUtilities.mapper.createArrayNode();
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
         whenGetArrayOption("sheets", options, sheets);
 
         whenGetIntegerOption("ignoreLines", options, 0);
@@ -217,7 +219,7 @@ public class ExcelImporterTests extends ImporterTest {
         InputStream stream = ClassLoader.getSystemResourceAsStream("dates.xls");
 
         parseOneFile(SUT, stream);
-        
+
         // The original value reads 2021-04-18 in the Excel file.
         // We make sure it is not shifted by a day because of timezone handling
         Object cellValue = project.rows.get(0).getCellValue(0);
@@ -236,19 +238,22 @@ public class ExcelImporterTests extends ImporterTest {
     }
 
     @Test
-    public void readMultiSheetXls() throws FileNotFoundException, IOException{
+    public void readMultiSheetXls() throws FileNotFoundException, IOException {
 
         ArrayNode sheets = ParsingUtilities.mapper.createArrayNode();
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 1\", fileNameAndSheetIndex: \"file-source#1\", rows: 31, selected: true}"));
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 2\", fileNameAndSheetIndex: \"file-source#2\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 1\", fileNameAndSheetIndex: \"file-source#1\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 2\", fileNameAndSheetIndex: \"file-source#2\", rows: 31, selected: true}"));
         whenGetArrayOption("sheets", options, sheets);
 
         whenGetIntegerOption("ignoreLines", options, 0);
         whenGetIntegerOption("headerLines", options, 0);
         whenGetIntegerOption("skipDataLines", options, 0);
         whenGetIntegerOption("limit", options, -1);
-        whenGetBooleanOption("storeBlankCellsAsNulls",options,true);
+        whenGetBooleanOption("storeBlankCellsAsNulls", options, true);
 
         InputStream stream = new FileInputStream(xlsFileWithMultiSheets);
 
@@ -262,20 +267,20 @@ public class ExcelImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(1).cells.size(), COLUMNS);
         Assert.assertEquals(project.columnModel.columns.size(), COLUMNS + SHEETS - 1);
 
-        Assert.assertEquals(((Number)project.rows.get(1).getCellValue(0)).doubleValue(),1.1, EPSILON);
-        Assert.assertEquals(((Number)project.rows.get(2).getCellValue(0)).doubleValue(),2.2, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(1).getCellValue(0)).doubleValue(), 1.1, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(2).getCellValue(0)).doubleValue(), 2.2, EPSILON);
         // Check the value read from the second sheet.
-        Assert.assertEquals(((Number)project.rows.get(ROWS).getCellValue(0)).doubleValue(),0.0, EPSILON);
-        Assert.assertEquals(((Number)project.rows.get(ROWS).getCellValue(COLUMNS)).doubleValue(),1.0, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(ROWS).getCellValue(0)).doubleValue(), 0.0, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(ROWS).getCellValue(COLUMNS)).doubleValue(), 1.0, EPSILON);
 
-        Assert.assertFalse((Boolean)project.rows.get(1).getCellValue(1));
-        Assert.assertTrue((Boolean)project.rows.get(2).getCellValue(1));
+        Assert.assertFalse((Boolean) project.rows.get(1).getCellValue(1));
+        Assert.assertTrue((Boolean) project.rows.get(2).getCellValue(1));
 
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(2))); // Calendar
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(3))); // Date
 
-        Assert.assertEquals((String)project.rows.get(1).getCellValue(4)," Row 1 Col 5");
-        Assert.assertNull((String)project.rows.get(1).getCellValue(5));
+        Assert.assertEquals((String) project.rows.get(1).getCellValue(4), " Row 1 Col 5");
+        Assert.assertNull((String) project.rows.get(1).getCellValue(5));
 
         // We will read SHEETS sheets from created xls file.
         verify(options, times(SHEETS)).get("ignoreLines");
@@ -286,19 +291,22 @@ public class ExcelImporterTests extends ImporterTest {
     }
 
     @Test
-    public void readMultiSheetXlsx() throws FileNotFoundException, IOException{
+    public void readMultiSheetXlsx() throws FileNotFoundException, IOException {
 
         ArrayNode sheets = ParsingUtilities.mapper.createArrayNode();
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 1\", fileNameAndSheetIndex: \"file-source#1\", rows: 31, selected: true}"));
-        sheets.add(ParsingUtilities.mapper.readTree("{name: \"file-source#Test Sheet 2\", fileNameAndSheetIndex: \"file-source#2\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 0\", fileNameAndSheetIndex: \"file-source#0\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 1\", fileNameAndSheetIndex: \"file-source#1\", rows: 31, selected: true}"));
+        sheets.add(ParsingUtilities.mapper
+                .readTree("{name: \"file-source#Test Sheet 2\", fileNameAndSheetIndex: \"file-source#2\", rows: 31, selected: true}"));
         whenGetArrayOption("sheets", options, sheets);
 
         whenGetIntegerOption("ignoreLines", options, 0);
         whenGetIntegerOption("headerLines", options, 0);
         whenGetIntegerOption("skipDataLines", options, 0);
         whenGetIntegerOption("limit", options, -1);
-        whenGetBooleanOption("storeBlankCellsAsNulls",options,true);
+        whenGetBooleanOption("storeBlankCellsAsNulls", options, true);
 
         InputStream stream = new FileInputStream(xlsxFileWithMultiSheets);
 
@@ -312,20 +320,20 @@ public class ExcelImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(1).cells.size(), COLUMNS);
         Assert.assertEquals(project.columnModel.columns.size(), COLUMNS + SHEETS - 1);
 
-        Assert.assertEquals(((Number)project.rows.get(1).getCellValue(0)).doubleValue(),1.1, EPSILON);
-        Assert.assertEquals(((Number)project.rows.get(2).getCellValue(0)).doubleValue(),2.2, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(1).getCellValue(0)).doubleValue(), 1.1, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(2).getCellValue(0)).doubleValue(), 2.2, EPSILON);
         // Check the value read from the second sheet.
-        Assert.assertEquals(((Number)project.rows.get(ROWS).getCellValue(0)).doubleValue(),0.0, EPSILON);
-        Assert.assertEquals(((Number)project.rows.get(ROWS).getCellValue(COLUMNS)).doubleValue(),1.0, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(ROWS).getCellValue(0)).doubleValue(), 0.0, EPSILON);
+        Assert.assertEquals(((Number) project.rows.get(ROWS).getCellValue(COLUMNS)).doubleValue(), 1.0, EPSILON);
 
-        Assert.assertFalse((Boolean)project.rows.get(1).getCellValue(1));
-        Assert.assertTrue((Boolean)project.rows.get(2).getCellValue(1));
+        Assert.assertFalse((Boolean) project.rows.get(1).getCellValue(1));
+        Assert.assertTrue((Boolean) project.rows.get(2).getCellValue(1));
 
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(2))); // Calendar
         assertTrue(ParsingUtilities.isDate(project.rows.get(1).getCellValue(3))); // Date
 
-        Assert.assertEquals((String)project.rows.get(1).getCellValue(4)," Row 1 Col 5");
-        Assert.assertNull((String)project.rows.get(1).getCellValue(5));
+        Assert.assertEquals((String) project.rows.get(1).getCellValue(4), " Row 1 Col 5");
+        Assert.assertNull((String) project.rows.get(1).getCellValue(5));
 
         // We will read SHEETS sheets from created xls file.
         verify(options, times(SHEETS)).get("ignoreLines");
@@ -365,7 +373,7 @@ public class ExcelImporterTests extends ImporterTest {
         return file;
     }
 
-   private static File createSheetsWithDifferentColumns(boolean xml) {
+    private static File createSheetsWithDifferentColumns(boolean xml) {
 
         final Workbook wb = xml ? new XSSFWorkbook() : new HSSFWorkbook();
 
@@ -395,41 +403,40 @@ public class ExcelImporterTests extends ImporterTest {
         return file;
     }
 
-private static void createDataRow(Sheet sheet, int row, CellStyle dateCellStyle, int extra_columns) {
-    int col = 0;
-    Row r = sheet.createRow(row);
-    Cell c;
+    private static void createDataRow(Sheet sheet, int row, CellStyle dateCellStyle, int extra_columns) {
+        int col = 0;
+        Row r = sheet.createRow(row);
+        Cell c;
 
+        c = r.createCell(col++);
+        c.setCellValue(row * 1.1); // double
 
-    c = r.createCell(col++);
-    c.setCellValue(row * 1.1); // double
+        c = r.createCell(col++);
+        c.setCellValue(row % 2 == 0); // boolean
 
-    c = r.createCell(col++);
-    c.setCellValue(row % 2 == 0); // boolean
+        c = r.createCell(col++);
+        c.setCellValue(Calendar.getInstance()); // calendar
+        c.setCellStyle(dateCellStyle);
 
-    c = r.createCell(col++);
-    c.setCellValue(Calendar.getInstance()); // calendar
-    c.setCellStyle(dateCellStyle);
+        c = r.createCell(col++);
+        c.setCellValue(new Date()); // date
+        c.setCellStyle(dateCellStyle);
 
-    c = r.createCell(col++);
-    c.setCellValue(new Date()); // date
-    c.setCellStyle(dateCellStyle);
+        c = r.createCell(col++);
+        c.setCellValue(" Row " + row + " Col " + col); // string
 
-    c = r.createCell(col++);
-    c.setCellValue(" Row " + row + " Col " + col); // string
-
-    c = r.createCell(col++);
-    c.setCellValue(""); // string
+        c = r.createCell(col++);
+        c.setCellValue(""); // string
 
 //    HSSFHyperlink hl = new HSSFHyperlink(HSSFHyperlink.LINK_URL);
 //    hl.setLabel(cellData.text);
 //    hl.setAddress(cellData.link);
 
-    // Create extra columns to ensure sheet(i+1) has more columns than sheet(i)
-    for(int i = 0; i < extra_columns; i++){
-        c = r.createCell(col++);
-        c.setCellValue(i + extra_columns);
+        // Create extra columns to ensure sheet(i+1) has more columns than sheet(i)
+        for (int i = 0; i < extra_columns; i++) {
+            c = r.createCell(col++);
+            c.setCellValue(i + extra_columns);
+        }
     }
-}
 
 }
