@@ -53,10 +53,10 @@ public class TsvCsvImporterTests extends ImporterTest {
         logger = LoggerFactory.getLogger(this.getClass());
     }
 
-    //constants
+    // constants
     String SAMPLE_ROW = "NDB_No,Shrt_Desc,Water";
 
-    //System Under Test
+    // System Under Test
     SeparatorBasedImporter SUT = null;
 
     @Override
@@ -68,22 +68,22 @@ public class TsvCsvImporterTests extends ImporterTest {
 
     @Override
     @AfterMethod
-    public void tearDown(){
+    public void tearDown() {
         SUT = null;
         super.tearDown();
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readJustColumns(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readJustColumns(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3";
-        
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -92,20 +92,19 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readSimpleData_CSV_1Header_1Row(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readSimpleData_CSV_1Header_1Row(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "data1" + inputSeparator + "data2" + inputSeparator + "data3";
-        
-        
+                "data1" + inputSeparator + "data2" + inputSeparator + "data3";
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
-        
+
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
         Assert.assertEquals(project.columnModel.columns.get(1).getName(), "col2");
@@ -118,17 +117,17 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readSimpleData_CSV_1Header_1Row_GuessValues(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readSimpleData_CSV_1Header_1Row_GuessValues(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "data1" + inputSeparator + "234" + inputSeparator + "data3";
-        
+                "data1" + inputSeparator + "234" + inputSeparator + "data3";
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, true, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -143,16 +142,16 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readSimpleData_0Header_1Row(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readSimpleData_0Header_1Row(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "data1" + inputSeparator + "data2" + inputSeparator + "data3";
-        
+
         try {
             prepareOptions(sep, -1, 0, 0, 0, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "Column 1");
@@ -165,17 +164,17 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, "data3");
     }
 
-    @Test(groups = {  }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void readDoesNotTrimLeadingTrailingWhitespace(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void readDoesNotTrimLeadingTrailingWhitespace(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = " data1 " + inputSeparator + " 3.4 " + inputSeparator + " data3 ";
-        
+
         try {
             prepareOptions(sep, -1, 0, 0, 0, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.rows.size(), 1);
@@ -186,16 +185,16 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readDoesNotTrimLeadingWhitespace(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readDoesNotTrimLeadingWhitespace(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = " data1" + inputSeparator + " 12" + inputSeparator + " data3";
-        
+
         try {
             prepareOptions(sep, -1, 0, 0, 0, true, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.rows.size(), 1);
@@ -205,17 +204,17 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, " data3");
     }
 
-    @Test(groups = {  }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void readTrimsLeadingTrailingWhitespaceOnTrimStrings(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void readTrimsLeadingTrailingWhitespaceOnTrimStrings(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = " data1 " + inputSeparator + " 3.4 " + inputSeparator + " data3 ";
 
         try {
             prepareOptions(sep, -1, 0, 0, 0, false, false, true);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.rows.size(), 1);
@@ -225,17 +224,17 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, "data3");
     }
 
-    @Test(groups = {  }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void readDoesNotTrimLeadingTrailingWhitespaceOnNoTrimStrings(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void readDoesNotTrimLeadingTrailingWhitespaceOnNoTrimStrings(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = " data1 " + inputSeparator + " 3.4 " + inputSeparator + " data3 ";
 
         try {
             prepareOptions(sep, -1, 0, 0, 0, false, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.rows.size(), 1);
@@ -244,18 +243,18 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(1).value, " 3.4 ");
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, " data3 ");
     }
-    
-    @Test(groups = {  }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void trimAndAutodetectDatatype(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void trimAndAutodetectDatatype(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = " data1 " + inputSeparator + " 3.4 " + inputSeparator + " data3 ";
 
         try {
             prepareOptions(sep, -1, 0, 0, 0, true, false, true);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.rows.size(), 1);
@@ -265,18 +264,17 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, "data3");
     }
 
-
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readCanAddNull(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readCanAddNull(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = " data1" + inputSeparator + inputSeparator + " data3";
-        
+
         try {
             prepareOptions(sep, -1, 0, 0, 0, true, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.rows.size(), 1);
@@ -287,18 +285,18 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readSimpleData_2Header_1Row(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readSimpleData_2Header_1Row(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "sub1" + inputSeparator + "sub2" + inputSeparator + "sub3\n" +
-                       "data1" + inputSeparator + "data2" + inputSeparator + "data3";
-        
+                "sub1" + inputSeparator + "sub2" + inputSeparator + "sub3\n" +
+                "data1" + inputSeparator + "data2" + inputSeparator + "data3";
+
         try {
             prepareOptions(sep, -1, 0, 0, 2, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1 sub1");
@@ -312,17 +310,18 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readSimpleData_RowLongerThanHeader(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readSimpleData_RowLongerThanHeader(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-        "data1" + inputSeparator + "data2" + inputSeparator + "data3" + inputSeparator + "data4" + inputSeparator + "data5" + inputSeparator + "data6";
-        
+                "data1" + inputSeparator + "data2" + inputSeparator + "data3" + inputSeparator + "data4" + inputSeparator + "data5"
+                + inputSeparator + "data6";
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 6);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -341,18 +340,18 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(5).value, "data6");
     }
 
-    @Test(groups = { }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void readQuotedData(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void readQuotedData(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "\"\"\"To Be\"\" is often followed by \"\"or not To Be\"\"\"" + inputSeparator + "data2";
-        
+                "\"\"\"To Be\"\" is often followed by \"\"or not To Be\"\"\"" + inputSeparator + "data2";
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -365,18 +364,18 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readIgnoreFirstLine(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readIgnoreFirstLine(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "ignore1\n" +
-                       "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "data1" + inputSeparator + "data2" + inputSeparator + "data3";
-        
+                "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
+                "data1" + inputSeparator + "data2" + inputSeparator + "data3";
+
         try {
             prepareOptions(sep, -1, 0, 1, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -390,18 +389,18 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readSkipFirstDataLine(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readSkipFirstDataLine(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "skip1\n" +
-                       "data1" + inputSeparator + "data2" + inputSeparator + "data3";
-        
+                "skip1\n" +
+                "data1" + inputSeparator + "data2" + inputSeparator + "data3";
+
         try {
             prepareOptions(sep, -1, 1, 0, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -415,22 +414,22 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readIgnore3_Header2_Skip1(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readIgnore3_Header2_Skip1(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "ignore1\n" +
-                       "ignore2\n" +
-                       "ignore3\n" +
-                       "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "sub1" + inputSeparator + "sub2" + inputSeparator + "sub3\n" +
-                       "skip1\n" +
-                       "data1" + inputSeparator + "data2" + inputSeparator + "data3";
-        
+                "ignore2\n" +
+                "ignore3\n" +
+                "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
+                "sub1" + inputSeparator + "sub2" + inputSeparator + "sub3\n" +
+                "skip1\n" +
+                "data1" + inputSeparator + "data2" + inputSeparator + "data3";
+
         try {
             prepareOptions(sep, -1, 1, 3, 2, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1 sub1");
@@ -443,26 +442,28 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, "data3");
     }
 
-    @Test(groups = {  }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void readIgnore3_Header2_Skip2_limit2(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void readIgnore3_Header2_Skip2_limit2(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "ignore1\n" +
-                       "ignore2\n" +
-                       "ignore3\n" +
-                       "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-                       "sub1" + inputSeparator + "sub2" + inputSeparator + "sub3\n" +
-                       "skip1\n" +
-                       "skip2\n" +
-                       "data-row1-cell1" + inputSeparator + "data-row1-cell2" + inputSeparator + "data-row1-cell3\n" +
-                       "data-row2-cell1" + inputSeparator + "data-row2-cell2" + inputSeparator + "\n" + //missing last data point of this row on purpose
-                       "data-row3-cell1" + inputSeparator + "data-row3-cell2" + inputSeparator + "data-row1-cell3";
-        
+                "ignore2\n" +
+                "ignore3\n" +
+                "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
+                "sub1" + inputSeparator + "sub2" + inputSeparator + "sub3\n" +
+                "skip1\n" +
+                "skip2\n" +
+                "data-row1-cell1" + inputSeparator + "data-row1-cell2" + inputSeparator + "data-row1-cell3\n" +
+                "data-row2-cell1" + inputSeparator + "data-row2-cell2" + inputSeparator + "\n" + // missing last data
+                                                                                                 // point of this row on
+                                                                                                 // purpose
+                "data-row3-cell1" + inputSeparator + "data-row3-cell2" + inputSeparator + "data-row1-cell3";
+
         try {
             prepareOptions(sep, 2, 2, 3, 2, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1 sub1");
@@ -480,15 +481,15 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void ignoreQuotes(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void ignoreQuotes(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "data1" + inputSeparator + "data2\"" + inputSeparator + "data3" + inputSeparator + "data4";
         try {
             prepareOptions(sep, -1, 0, 0, 0, false, true);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 4);
         Assert.assertEquals(project.rows.size(), 1);
@@ -498,18 +499,18 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, "data3");
     }
 
-    @Test(groups = { }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void readWithMultiLinedQuotedData(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void readWithMultiLinedQuotedData(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-            "\"\"\"To\n Be\"\" is often followed by \"\"or not To\n Be\"\"\"" + inputSeparator + "data2";
-        
+                "\"\"\"To\n Be\"\" is often followed by \"\"or not To\n Be\"\"\"" + inputSeparator + "data2";
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -521,18 +522,18 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(1).value, "data2");
     }
 
-    @Test(groups = {  }, dataProvider = "CSV-TSV-AutoDetermine")
-    public void readWithMultiLinedQuotedDataAndBlankLines(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    @Test(groups = {}, dataProvider = "CSV-TSV-AutoDetermine")
+    public void readWithMultiLinedQuotedDataAndBlankLines(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "col1" + inputSeparator + "col2" + inputSeparator + "col3\n" +
-            "\"A line with many \n\n\n\n\n empty lines\"" + inputSeparator + "data2";
-        
+                "\"A line with many \n\n\n\n\n empty lines\"" + inputSeparator + "data2";
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, false, false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -544,22 +545,20 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(1).value, "data2");
     }
 
-
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void customQuoteCharacter(String sep){
-        //create input to test with
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void customQuoteCharacter(String sep) {
+        // create input to test with
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "'col1'" + inputSeparator + "'col2'" + inputSeparator + "'col3'\n" +
-                       "'data1'" + inputSeparator + "'data2'" + inputSeparator + "'data3'";
-        
-        
+                "'data1'" + inputSeparator + "'data2'" + inputSeparator + "'data3'";
+
         try {
             prepareOptions(sep, -1, 0, 0, 1, false, false, "'");
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
-        
+
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
         Assert.assertEquals(project.columnModel.columns.get(1).getName(), "col2");
@@ -570,18 +569,18 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(1).value, "data2");
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, "data3");
     }
-    
+
     @Test(dataProvider = "CSV-TSV-AutoDetermine")
-    public void readCustomColumnNames(String sep){
-        //create input
-        String inputSeparator =  sep == null ? "\t" : sep;
+    public void readCustomColumnNames(String sep) {
+        // create input
+        String inputSeparator = sep == null ? "\t" : sep;
         String input = "data1" + inputSeparator + "data2" + inputSeparator + "data3\n";
-        
+
         try {
-            prepareOptions(sep, -1, 0, 0, 1, false, false,"\"","[\"col1\",\"col2\",\"col3\"]", false);
+            prepareOptions(sep, -1, 0, 0, 1, false, false, "\"", "[\"col1\",\"col2\",\"col3\"]", false);
             parseOneFile(SUT, new StringReader(input));
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
         Assert.assertEquals(project.columnModel.columns.size(), 3);
         Assert.assertEquals(project.columnModel.columns.get(0).getName(), "col1");
@@ -591,59 +590,59 @@ public class TsvCsvImporterTests extends ImporterTest {
         Assert.assertEquals(project.rows.get(0).cells.get(1).value, "data2");
         Assert.assertEquals(project.rows.get(0).cells.get(2).value, "data3");
     }
-    
-    //---------------------read tests------------------------
+
+    // ---------------------read tests------------------------
     @Test
     public void readCsvWithProperties() {
         StringReader reader = new StringReader(SAMPLE_ROW);
-        
+
         prepareOptions(",", -1, 0, 0, 0, true, true);
-        
+
         try {
             parseOneFile(SUT, reader);
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
-        
+
         Assert.assertEquals(project.rows.size(), 1);
         Assert.assertEquals(project.rows.get(0).cells.size(), 3);
-        Assert.assertEquals((String)project.rows.get(0).cells.get(0).value, "NDB_No");
-        Assert.assertEquals((String)project.rows.get(0).cells.get(1).value, "Shrt_Desc");
-        Assert.assertEquals((String)project.rows.get(0).cells.get(2).value, "Water");
+        Assert.assertEquals((String) project.rows.get(0).cells.get(0).value, "NDB_No");
+        Assert.assertEquals((String) project.rows.get(0).cells.get(1).value, "Shrt_Desc");
+        Assert.assertEquals((String) project.rows.get(0).cells.get(2).value, "Water");
     }
 
     @Test
-    public void readCsvWithPropertiesIgnoreQuotes(){
+    public void readCsvWithPropertiesIgnoreQuotes() {
         String input = "data1,data2\",data3,data4";
         StringReader reader = new StringReader(input);
 
         prepareOptions(",", -1, 0, 0, 0, true, true);
-        
+
         try {
             parseOneFile(SUT, reader);
         } catch (Exception e) {
-            Assert.fail("Exception during file parse",e);
+            Assert.fail("Exception during file parse", e);
         }
-        
+
         Assert.assertEquals(project.rows.size(), 1);
         Assert.assertEquals(project.rows.get(0).cells.size(), 4);
-        Assert.assertEquals((String)project.rows.get(0).cells.get(0).value, "data1");
-        Assert.assertEquals((String)project.rows.get(0).cells.get(1).value, "data2");
-        Assert.assertEquals((String)project.rows.get(0).cells.get(2).value, "data3");
-        Assert.assertEquals((String)project.rows.get(0).cells.get(3).value, "data4");
+        Assert.assertEquals((String) project.rows.get(0).cells.get(0).value, "data1");
+        Assert.assertEquals((String) project.rows.get(0).cells.get(1).value, "data2");
+        Assert.assertEquals((String) project.rows.get(0).cells.get(2).value, "data3");
+        Assert.assertEquals((String) project.rows.get(0).cells.get(3).value, "data4");
     }
 
-    //--helpers--
+    // --helpers--
     /**
      * Used for parameterized testing for both SeparatorParser and TsvCsvParser.
      */
     @DataProvider(name = "CSV-TSV-AutoDetermine")
-    public Object[][] CSV_TSV_or_AutoDetermine(){
-        return new Object[][]{
-                {","},{"\t"},{null}
+    public Object[][] CSV_TSV_or_AutoDetermine() {
+        return new Object[][] {
+                { "," }, { "\t" }, { null }
         };
     }
-    
+
     protected void prepareOptions(
             String sep, int limit, int skip, int ignoreLines,
             int headerLines, boolean guessValueType, boolean ignoreQuotes) {
@@ -651,10 +650,10 @@ public class TsvCsvImporterTests extends ImporterTest {
     }
 
     private void prepareOptions(
-        String sep, int limit, int skip, int ignoreLines,
-        int headerLines, boolean guessValueType, boolean ignoreQuotes, String quoteCharacter) {
-        
-        prepareOptions(sep, limit, skip, ignoreLines, headerLines, guessValueType, ignoreQuotes, quoteCharacter,"[]", false);
+            String sep, int limit, int skip, int ignoreLines,
+            int headerLines, boolean guessValueType, boolean ignoreQuotes, String quoteCharacter) {
+
+        prepareOptions(sep, limit, skip, ignoreLines, headerLines, guessValueType, ignoreQuotes, quoteCharacter, "[]", false);
     }
 
     protected void prepareOptions(
@@ -669,21 +668,22 @@ public class TsvCsvImporterTests extends ImporterTest {
         whenGetBooleanOption("processQuotes", options, !ignoreQuotes);
         whenGetBooleanOption("trimStrings", options, trimStrings);
     }
-    
+
     protected void prepareOptions(
             String sep, int limit, int skip, int ignoreLines,
-            int headerLines, boolean guessValueType, boolean ignoreQuotes, String quoteCharacter, String columnNames, boolean includeArchiveFileName) {
-            
-            whenGetStringOption("separator", options, sep);
-            whenGetStringOption("quoteCharacter", options, quoteCharacter);
-            whenGetIntegerOption("limit", options, limit);
-            whenGetIntegerOption("skipDataLines", options, skip);
-            whenGetIntegerOption("ignoreLines", options, ignoreLines);
-            whenGetIntegerOption("headerLines", options, headerLines);
-            whenGetBooleanOption("guessCellValueTypes", options, guessValueType);
-            whenGetBooleanOption("processQuotes", options, !ignoreQuotes);
-            whenGetBooleanOption("storeBlankCellsAsNulls", options, true);
-            whenGetArrayOption("columnNames", options, ParsingUtilities.evaluateJsonStringToArrayNode(columnNames));
-            whenGetBooleanOption("includeArchiveFileName", options, includeArchiveFileName);
-        }
+            int headerLines, boolean guessValueType, boolean ignoreQuotes, String quoteCharacter, String columnNames,
+            boolean includeArchiveFileName) {
+
+        whenGetStringOption("separator", options, sep);
+        whenGetStringOption("quoteCharacter", options, quoteCharacter);
+        whenGetIntegerOption("limit", options, limit);
+        whenGetIntegerOption("skipDataLines", options, skip);
+        whenGetIntegerOption("ignoreLines", options, ignoreLines);
+        whenGetIntegerOption("headerLines", options, headerLines);
+        whenGetBooleanOption("guessCellValueTypes", options, guessValueType);
+        whenGetBooleanOption("processQuotes", options, !ignoreQuotes);
+        whenGetBooleanOption("storeBlankCellsAsNulls", options, true);
+        whenGetArrayOption("columnNames", options, ParsingUtilities.evaluateJsonStringToArrayNode(columnNames));
+        whenGetBooleanOption("includeArchiveFileName", options, includeArchiveFileName);
+    }
 }
