@@ -44,12 +44,12 @@ function ExpressionPreviewDialog(title, cellIndex, rowIndices, values, expressio
     
     this._elmts = DOM.bind(html);
     
-    $('<button class="button"></button>').html($.i18n('core-buttons/ok')).click(function() {
+    $('<button class="button"></button>').html($.i18n('core-buttons/ok')).on('click',function() {
         DialogSystem.dismissUntil(self._level - 1);
         self._onDone(self._previewWidget.getExpression(true));
     }).appendTo(footer);
     
-    $('<button class="button"></button>').text($.i18n('core-buttons/cancel')).click(function() {
+    $('<button class="button"></button>').text($.i18n('core-buttons/cancel')).on('click',function() {
         DialogSystem.dismissUntil(self._level - 1);
     }).appendTo(footer);
     
@@ -119,7 +119,7 @@ ExpressionPreviewDialog.Widget = function(
     $("#expression-preview-tabs").tabs();
     
     this._elmts.expressionPreviewLanguageSelect[0].value = language;
-    this._elmts.expressionPreviewLanguageSelect.bind("change", function() {
+    this._elmts.expressionPreviewLanguageSelect.on("change", function() {
         Cookies.set("scripting.lang", this.value, {"SameSite" : "Lax"});
         self.update();
     });
@@ -127,11 +127,11 @@ ExpressionPreviewDialog.Widget = function(
     var self = this;
     this._elmts.expressionPreviewTextarea
         .val(this.expression)
-        .bind("keyup change input",function(){
+        .on("keyup change input",function(){
             self._scheduleUpdate();
         })
-        .select()
-        .focus();
+        .trigger('select')
+        .trigger('focus');
 
     this._elmts.or_dialog_expr.html($.i18n('core-dialogs/expression'));
     this._elmts.or_dialog_lang.html($.i18n('core-dialogs/language'));
@@ -147,7 +147,7 @@ ExpressionPreviewDialog.Widget = function(
 };
 
 ExpressionPreviewDialog.Widget.prototype.getExpression = function(commit) {
-    var s = $.trim(this.expression || "");
+    var s = jQueryTrim(this.expression || "");
     if (!s.length) {
         return null;
     }
@@ -284,7 +284,7 @@ ExpressionPreviewDialog.Widget.prototype._renderExpressionHistory = function(dat
         $('<a href="javascript:{}">&nbsp;</a>')
                 .addClass(entry.starred ? "data-table-star-on" : "data-table-star-off")
                 .appendTo(tr.insertCell(0))
-                .click(function() {
+                .on('click',function() {
                     Refine.postCSRF(
                         "command/core/toggle-starred-expression",
                         {
@@ -295,17 +295,17 @@ ExpressionPreviewDialog.Widget.prototype._renderExpressionHistory = function(dat
                             renderEntry(self,tr,entry);
                             self._renderStarredExpressionsTab();
                         },
-                        "json"
+                        ""
                     );
                 });
         
-        $('<a href="javascript:{}">'+$.i18n('core-dialogs/reuse')+'</a>').appendTo(tr.insertCell(1)).click(function() {
+        $('<a href="javascript:{}">'+$.i18n('core-dialogs/reuse')+'</a>').appendTo(tr.insertCell(1)).on('click',function() {
             self._elmts.expressionPreviewTextarea[0].value = o.expression;
             self._elmts.expressionPreviewLanguageSelect[0].value = o.language;
             
             $("#expression-preview-tabs").tabs();
             
-            self._elmts.expressionPreviewTextarea.select().focus();
+            self._elmts.expressionPreviewTextarea.trigger('select').trigger('focus');
             
             self.update();
         });
@@ -332,7 +332,7 @@ ExpressionPreviewDialog.Widget.prototype._renderStarredExpressionsTab = function
         function(data) {
             self._renderStarredExpressions(data);
         },
-        "json"
+        ""
     );
 };
 
@@ -350,14 +350,14 @@ ExpressionPreviewDialog.Widget.prototype._renderStarredExpressions = function(da
         var tr = table.insertRow(table.rows.length);
         var o = Scripting.parse(entry.code);
         
-        $('<a href="javascript:{}">'+$.i18n('core-dialogs/remove')+'</a>').appendTo(tr.insertCell(0)).click(function() {
+        $('<a href="javascript:{}">'+$.i18n('core-dialogs/remove')+'</a>').appendTo(tr.insertCell(0)).on('click',function() {
             var removeExpression = DialogSystem.createDialog();
                 removeExpression.width("250px");
             var removeExpressionHead = $('<div></div>').addClass("dialog-header").text($.i18n('core-dialogs/unstar-expression'))
                 .appendTo(removeExpression);
             var removeExpressionFooter = $('<div></div>').addClass("dialog-footer").appendTo(removeExpression);
 
-            $('<button class="button"></button>').html($.i18n('core-buttons/ok')).click(function() {
+            $('<button class="button"></button>').html($.i18n('core-buttons/ok')).on('click',function() {
                 Refine.postCSRF(
                     "command/core/toggle-starred-expression",
                     { expression: entry.code, returnList: true },
@@ -370,20 +370,20 @@ ExpressionPreviewDialog.Widget.prototype._renderStarredExpressions = function(da
                 DialogSystem.dismissUntil(DialogSystem._layers.length - 1);
             }).appendTo(removeExpressionFooter);
 
-            $('<button class="button" style="float:right;"></button>').text($.i18n('core-buttons/cancel')).click(function() {
+            $('<button class="button" style="float:right;"></button>').text($.i18n('core-buttons/cancel')).on('click',function() {
                 DialogSystem.dismissUntil(DialogSystem._layers.length - 1);
             }).appendTo(removeExpressionFooter);
 
             this._level = DialogSystem.showDialog(removeExpression);
         });
         
-        $('<a href="javascript:{}">Reuse</a>').appendTo(tr.insertCell(1)).click(function() {
+        $('<a href="javascript:{}">Reuse</a>').appendTo(tr.insertCell(1)).on('click',function() {
             self._elmts.expressionPreviewTextarea[0].value = o.expression;
             self._elmts.expressionPreviewLanguageSelect[0].value = o.language;
             
             $("#expression-preview-tabs").tabs();
             
-            self._elmts.expressionPreviewTextarea.select().focus();
+            self._elmts.expressionPreviewTextarea.trigger('select').trigger('focus');
             
             self.update();
         });
@@ -408,7 +408,7 @@ ExpressionPreviewDialog.Widget.prototype._scheduleUpdate = function() {
 
 ExpressionPreviewDialog.Widget.prototype.update = function() {
     var self = this;
-    var expression = this.expression = $.trim(this._elmts.expressionPreviewTextarea[0].value);
+    var expression = this.expression = jQueryTrim(this._elmts.expressionPreviewTextarea[0].value);
     var params = {
         project: theProject.id,
         cellIndex: this._cellIndex
