@@ -41,6 +41,8 @@ function DataTableCellUI(dataTableView, cell, rowIndex, cellIndex, td) {
   this._render();
 }
 
+var reconMatchSilimilarCellsByDefault = true;
+
 DataTableCellUI.previewMatchedCells = true;
 
 (function() {
@@ -73,9 +75,9 @@ DataTableCellUI.prototype._render = function() {
   editLink.addEventListener('click', function() { self._startEdit(this); });
 
   $(this._td).empty()
-  .unbind()
-  .mouseenter(function() { editLink.style.visibility = "visible" })
-  .mouseleave(function() { editLink.style.visibility = "hidden" });
+  .off()
+  .on('mouseenter',function() { editLink.style.visibility = "visible" })
+  .on('mouseleave',function() { editLink.style.visibility = "hidden" });
 
   if (!cell || ("v" in cell && cell.v === null)) {
     var nullSpan = document.createElement('span');
@@ -138,7 +140,7 @@ DataTableCellUI.prototype._render = function() {
       $('<a href="javascript:{}"></a>')
       .text($.i18n('core-views/choose-match'))
       .addClass("data-table-recon-action")
-      .appendTo(divContentRecon).click(function(evt) {
+      .appendTo(divContentRecon).on('click',function(evt) {
         self._doRematch();
       });
     } else if (r.j == "matched" && "m" in r && r.m !== null) {
@@ -161,7 +163,7 @@ DataTableCellUI.prototype._render = function() {
       .text($.i18n('core-views/choose-match'))
       .addClass("data-table-recon-action")
       .appendTo(divContentRecon)
-      .click(function(evt) {
+      .on('click',function(evt) {
         self._doRematch();
       });
     } else {
@@ -178,14 +180,14 @@ DataTableCellUI.prototype._render = function() {
             $('<a href="javascript:{}">&nbsp;</a>')
             .addClass("data-table-recon-match-similar")
             .attr("title", $.i18n('core-views/match-all-cells'))
-            .appendTo(liSpan).click(function(evt) {
+            .appendTo(liSpan).on('click',function(evt) {
               self._doMatchTopicToSimilarCells(candidate);
             });
 
             $('<a href="javascript:{}">&nbsp;</a>')
             .addClass("data-table-recon-match")
             .attr("title", $.i18n('core-views/match-this-cell') )
-            .appendTo(liSpan).click(function(evt) {
+            .appendTo(liSpan).on('click',function(evt) {
               self._doMatchTopicToOneCell(candidate);
             });
 
@@ -219,14 +221,14 @@ DataTableCellUI.prototype._render = function() {
         $('<a href="javascript:{}">&nbsp;</a>')
         .addClass("data-table-recon-match-similar")
         .attr("title", $.i18n('core-views/create-topic-cells'))
-        .appendTo(liNew).click(function(evt) {
+        .appendTo(liNew).on('click',function(evt) {
           self._doMatchNewTopicToSimilarCells();
         });
 
         $('<a href="javascript:{}">&nbsp;</a>')
         .addClass("data-table-recon-match")
         .attr("title", $.i18n('core-views/create-topic-cell'))
-        .appendTo(liNew).click(function(evt) {
+        .appendTo(liNew).on('click',function(evt) {
           self._doMatchNewTopicToOneCell();
         });
 
@@ -249,7 +251,7 @@ DataTableCellUI.prototype._render = function() {
         var extraChoices = $('<div>').addClass("data-table-recon-extra").appendTo(divContentRecon);
         if (addSuggest) {
           $('<a href="javascript:{}"></a>')
-          .click(function(evt) {
+          .on('click',function(evt) {
             self._searchForMatch(suggestOptions);
             return false;
           })
@@ -360,9 +362,16 @@ DataTableCellUI.prototype._searchForMatch = function(suggestOptions) {
   elmts.newButton.html($.i18n('core-buttons/new-topic'));
   elmts.clearButton.html($.i18n('core-buttons/dont-reconcile'));
   elmts.cancelButton.html($.i18n('core-buttons/cancel'));
+  
+	if (!reconMatchSilimilarCellsByDefault) {
+		elmts.radioSimilar[0].setAttribute("checked", false);
+		elmts.radioOne[0].setAttribute("checked", true);
+	}
 
   var level = DialogSystem.showDialog(frame);
   var dismiss = function() {
+	reconMatchSilimilarCellsByDefault = elmts.radioSimilar[0].checked;
+	  
     DialogSystem.dismissUntil(level - 1);
   };
 
@@ -416,10 +425,10 @@ DataTableCellUI.prototype._searchForMatch = function(suggestOptions) {
     dismiss();
   };
 
-  elmts.okButton.click(commit);
-  elmts.newButton.click(commitNew);
-  elmts.clearButton.click(commitClear);
-  elmts.cancelButton.click(dismiss);
+  elmts.okButton.on('click',commit);
+  elmts.newButton.on('click',commitNew);
+  elmts.clearButton.on('click',commitClear);
+  elmts.cancelButton.on('click',dismiss);
 
   var suggestOptions2 = $.extend({ align: "left" }, suggestOptions 
                           || { all_types: true, // FIXME: all_types isn't documented for Suggest.  Is it still implemented?
@@ -432,11 +441,11 @@ DataTableCellUI.prototype._searchForMatch = function(suggestOptions) {
   elmts.input
   .val(this._cell.v)
   .suggest(suggestOptions2)
-  .bind("fb-select", function(e, data) {
+  .on("fb-select", function(e, data) {
     match = data;
     commit();
   })
-  .focus()
+  .trigger('focus')
   .data("suggest").textchange();
 };
 
@@ -500,7 +509,7 @@ DataTableCellUI.prototype._previewCandidateTopic = function(candidate, elmt, pre
 
   var dismissMenu = function() {
      fakeMenu.remove();
-     fakeMenu.unbind();  
+     fakeMenu.off();  
   };
 
   if (showActions) {
@@ -510,15 +519,15 @@ DataTableCellUI.prototype._previewCandidateTopic = function(candidate, elmt, pre
     elmts.matchSimilarButton.html($.i18n('core-views/match-identical'));
     elmts.cancelButton.html($.i18n('core-buttons/cancel'));
     
-    elmts.matchButton.click(function() {
+    elmts.matchButton.on('click',function() {
         self._doMatchTopicToOneCell(candidate);
         dismissMenu();
     });
-    elmts.matchSimilarButton.click(function() {
+    elmts.matchSimilarButton.on('click',function() {
         self._doMatchTopicToSimilarCells(candidate);
         dismissMenu();
     });
-    elmts.cancelButton.click(function() {
+    elmts.cancelButton.on('click',function() {
         dismissMenu();
     });
   }
@@ -537,12 +546,12 @@ DataTableCellUI.prototype._previewOnHover = function(service, candidate, hoverEl
 
     if (preview) {
         var dismissCallback = null;
-        hoverElement.hover(function(evt) {
+        hoverElement.on('mouseenter',function(evt) {
         if (!evt.metaKey && !evt.ctrlKey) {
             dismissCallback = self._previewCandidateTopic(candidate, coreElement, preview, showActions);
             evt.preventDefault();
         }
-        }, function(evt) {
+        }).on('mouseleave',function(evt) {
         if(dismissCallback !== null) {
             dismissCallback();
         }
@@ -652,11 +661,11 @@ DataTableCellUI.prototype._startEdit = function(elmt) {
     }
   };
 
-  elmts.okButton.click(commit);
-  elmts.okallButton.click(commit);
+  elmts.okButton.on('click',commit);
+  elmts.okallButton.on('click',commit);
   elmts.textarea
   .text(originalContent)
-  .keydown(function(evt) {
+  .on('keydown',function(evt) {
     if (!evt.shiftKey) {
       if (evt.keyCode == 13) {
         if (evt.ctrlKey) {
@@ -669,10 +678,10 @@ DataTableCellUI.prototype._startEdit = function(elmt) {
       }
     }
   })
-  .select()
-  .focus();
+  .trigger('select')
+  .trigger('focus');
 
-  elmts.cancelButton.click(function() {
+  elmts.cancelButton.on('click',function() {
     MenuSystem.dismissAll();
   });
 };
